@@ -325,7 +325,7 @@ def equivalent_potential_temperature(pressure, temperature, dewpoint):
     e = saturation_vapor_pressure(dewpoint)
     r = saturation_mixing_ratio(pressure, dewpoint)
 
-    t_l = 56 + 1. / (1. / (td - 56) + np.log(t / td) / 800.) + 273.15
+    t_l = 56 + 1. / (1. / (td - 56) + np.log(t / td) / 800.)
     th_l = t * (100000. / (p - e)) ** kappa * (t / t_l) ** (0.28 * r)
     th_e = th_l * np.exp((3036. / t_l - 1.78) * r * (1 + 0.448 * r))
 
